# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _
from redsolutioncms.models import BaseSettings

class SeoSettings(BaseSettings):
    pass

class SeoModel(models.Model):
    settings = models.ForeignKey(SeoSettings, related_name='models')
    model = models.CharField(verbose_name=_('Mode'), max_length=255)



import os
from redsolutioncms.make import BaseMake
from redsolutioncms.models import CMSSettings
from seo.redsolution_setup.models import SeoSettings

class Make(BaseMake):
    def make(self):
        super(Make, self).make()
        seo_settings = SeoSettings.objects.get_settings()
        cms_settings = CMSSettings.objects.get_settings()
        cms_settings.render_to(['..', 'templates', 'base_seo.html'],
            'seo/redsolutioncms/base_seo.html', {
            'seo_settings': seo_settings,
        }, 'w')
        cms_settings.base_template = 'base_seo.html'
        cms_settings.save()

    def postmake(self):
        super(Make, self).postmake()
        seo_settings = SeoSettings.objects.get_settings()
        cms_settings = CMSSettings.objects.get_settings()
        cms_settings.render_to('settings.py', 'seo/redsolutioncms/settings.pyt', {
            'seo_settings': seo_settings,
        })

make = Make()



from django.contrib import admin
from seo.redsolution_setup.models import SeoSettings, SeoModel

class SeoModelInline(admin.TabularInline):
    model = SeoModel

class SeoSettingsForm(admin.ModelAdmin):
    model = SeoSettings
    inlines = [SeoModelInline]

try:
    admin.site.register(SeoSettings, SeoSettingsForm)
except admin.sites.AlreadyRegistered:
    pass
